offsettools.update_offset_values_of_component_in_seconds
========================================================

.. autofunction:: abjad.tools.offsettools.update_offset_values_of_component_in_seconds.update_offset_values_of_component_in_seconds
   :noindex:
